FieldX<T> class

Constructors

FieldX({required T initialValue, List<String? Function(T)> validators = const [], List<Future<String?> Function(T)> asyncValidators = const [], Duration? debounce})

Properties

error String?
no setter
errorStream Stream<String?>
no setter
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateStream Stream<FieldState<T>>
no setter
value → T
no setter
valueStream Stream<T>
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(T value, {bool validate = true}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited